@@ -37,6 +37,46 @@
 #include <QStandardPaths>
 
 Settings *Settings::s_pSetting = nullptr;
+
+CustemBackend::CustemBackend(const QString &filepath, QObject *parent)
+    : DSettingsBackend (parent),
+      m_settings (new QSettings(filepath, QSettings::IniFormat))
+{
+
+}
+
+void CustemBackend::doSync()
+{
+    m_settings->sync();
+}
+
+void CustemBackend::doSetOption(const QString &key, const QVariant &value)
+{
+    /*
+     * 将配置值写入config配置文件
+     * 为了规避数据写入重复或者错乱，配置写入之前上锁，写入结束后开锁
+     */
+    m_writeLock.lock();
+    m_settings->setValue(key, value);
+    m_settings->sync();
+    m_writeLock.unlock();
+}
+
+QStringList CustemBackend::keys() const
+{
+    QStringList keyList = m_settings->allKeys();
+
+    return keyList;
+}
+
+QVariant CustemBackend::getOption(const QString &key) const
+{
+    return m_settings->value(key);
+}
+
+CustemBackend::~CustemBackend()
+{}
+
 Settings::Settings(QWidget *parent)
     : QObject(parent)
 {
@@ -45,6 +85,7 @@ Settings::Settings(QWidget *parent)
                             .arg(qApp->organizationName())
                             .arg(qApp->applicationName());
 
+    removeLockFiles();
     m_backend = new QSettingBackend(strConfigPath);
 
     settings = DSettings::fromJsonFile(":/resources/settings.json");
@@ -489,6 +530,29 @@ DDialog *Settings::createDialog(const QString &title, const QString &content, co
     return dialog;
 }
 
+//删除config.conf配置文件目录下的.lock文件和.rmlock文件
+void Settings::removeLockFiles()
+{
+    QString configPath = QString("%1/%2/%3")
+            .arg(QStandardPaths::writableLocation(QStandardPaths::ConfigLocation))
+            .arg(qApp->organizationName())
+            .arg(qApp->applicationName());
+
+    QDir dir(configPath);
+    if (!dir.exists()) {
+        return;
+    }
+
+    dir.setFilter(QDir::Files);
+    QStringList nameList = dir.entryList();
+    for (auto name: nameList) {
+        if (name.contains(".lock") || name.contains(".rmlock")) {
+            QFile file(name);
+            file.remove();
+        }
+    }
+}
+
 void Settings::slotCustomshortcut(const QString &key, const QVariant &value)
 {
     auto keymap = settings->option("shortcuts.keymap.keymap");
