@@ -46,13 +46,26 @@
 class Utils
 {
 public:
+    /**
+     * @brief 区间交叉类型
+     */
+    enum RegionIntersectType {
+        ELeft,              ///< 活动区间在固定区间左侧 例如 [0, 9] 和 [-5, -1]
+        ERight,             ///< 活动区间在固定区间右侧 例如 [0, 9] 和 [10, 15]
+
+        EIntersectLeft,     ///< 活动区间在固定区间左侧存在范围重叠 例如 [0, 9] 和 [-5, 5]
+        EIntersectRight,    ///< 活动区间在固定区间右侧存在范围重叠 例如 [0, 9] 和 [5, 15]
+        EIntersectOutter,   ///< 活动区间包含固定区间            例如 [0, 9] 和 [-10, 10]
+        EIntersectInner,    ///< 活动区间处于固定区间内部         例如 [0, 9] 和 [5, 6]
+    };
+
     static QString getQrcPath(const QString &imageName);
     static QString getQssPath(const QString &qssName);
     static QSize getRenderSize(int fontSize, const QString &string);
     static void setFontSize(QPainter &painter, int textSize);
     static void applyQss(QWidget *widget, const QString &qssName);
     static QString getKeyshortcut(QKeyEvent *keyEvent);
-    static QString getKeyshortcutFromKeymap(Settings* settings, const QString &keyCategory, const QString &keyName);
+    static QString getKeyshortcutFromKeymap(Settings *settings, const QString &keyCategory, const QString &keyName);
     static bool fileExists(const QString &path);
     static bool fileIsWritable(const QString &path);
     static bool fileIsHome(const QString &path);
@@ -69,8 +82,11 @@ public:
     static QVariantMap getThemeMapFromPath(const QString &filepath);
     static bool isMimeTypeSupport(const QString &filepath);
     static bool isDraftFile(const QString &filepath);
+    // 返回文件是否为备份文件
+    static bool isBackupFile(const QString &filepath);
+    static QStringList cleanPath(const QStringList &filePaths);
     static const QStringList getEncodeList();
-    static QPixmap renderSVG(const QString &filePath, const QSize &size ,bool bIsScale = true);
+    static QPixmap renderSVG(const QString &filePath, const QSize &size, bool bIsScale = true);
     static QList<QColor> getHiglightColorList();
     /*******************************************************************************
      1. @函数:    clearChildrenFocus
@@ -81,9 +97,9 @@ public:
     *******************************************************************************/
     static void clearChildrenFocus(QObject *objParent);
     //清除　控件及子控件所以焦点　梁卫东　２０２０－０９－１４　１０：３４：１９
-    static void clearChildrenFoucusEx(QWidget* pWidget);
+    static void clearChildrenFoucusEx(QWidget *pWidget);
     //设置所有控件焦点 梁卫东　２０２０－０９－１５　１７：５５：１８
-    static void setChildrenFocus(QWidget* pWidget,Qt::FocusPolicy policy = Qt::StrongFocus);
+    static void setChildrenFocus(QWidget *pWidget, Qt::FocusPolicy policy = Qt::StrongFocus);
     //根据指定名称获取进程数量 秦浩玲　2021-01-26
     static int getProcessCountByName(const char *pstrName);
     //批量结束指定名称的进程 秦浩玲　2021-01-26
@@ -94,7 +110,7 @@ public:
     static bool activeWindowFromDock(quintptr winId);
 
     //判断是否共享文件夹且只读
-    static bool isShareDirAndReadOnly(const QString& filePath);
+    static bool isShareDirAndReadOnly(const QString &filePath);
 
 
     static float codecConfidenceForData(const QTextCodec *codec, const QByteArray &data, const QLocale::Country &country);
@@ -104,6 +120,12 @@ public:
 
     static bool isWayland();
 
+    // 计算换行内容 text: 原始文本内容， nWidth: 一行最大宽度， font:字体大小, nElideRow: 最大显示行数，超出最大行时，中间内容加···省略号显示
+    static QString lineFeed(const QString &text, int nWidth, const QFont &font, int nElidedRow = 2);
+
+    // 判断 [x1, y1] 和 [x2, y2] 区间是否存在交集，返回交集类型
+    static RegionIntersectType checkRegionIntersect(int x1, int y1, int x2, int y2);
+
 private:
     static QString m_systemLanguage;
 };
