@@ -38,9 +38,59 @@
 #include <DSettingsOption>
 #include <DMenuBar>
 #include <QFileInfo>
+#include <QEvent>
 
 DCORE_USE_NAMESPACE
 
+enum ReadLengthType {
+    EReadStepSize = 1 * 1024 * 1024,    // 单次读取文件最大长度
+};
+
+/**
+ * @brief 处理文件时使用的事件类型，处理解析文件数据时，
+ *      将此事件抛给事件队列，使用事件队列分发解析任务
+ */
+class ParseFileEvent : public QEvent
+{
+public:
+    enum Type {
+        EParseFile = QEvent::User + 1024,
+    };
+
+    ParseFileEvent();
+    virtual ~ParseFileEvent();
+
+    // 返回此事件的克隆对象，用于下次任务。
+    ParseFileEvent *clone();
+
+    // 内部公开数据
+    int             m_alreadyReadOffset = 0;    // 当前已读取文本大小
+    QByteArray      m_contentData;              // 文本内容
+    QTextCursor     m_cursor;                   // 插入光标
+    QTextCodec      *m_codec = nullptr;         // 编码
+};
+
+ParseFileEvent::ParseFileEvent()
+    : QEvent(static_cast<QEvent::Type>(EParseFile))
+{
+}
+
+ParseFileEvent::~ParseFileEvent()
+{
+}
+
+ParseFileEvent *ParseFileEvent::clone()
+{
+    // 创建克隆对象，复制数据(浅拷贝)
+    ParseFileEvent *cloneEvent = new ParseFileEvent;
+    cloneEvent->m_contentData = this->m_contentData;
+    cloneEvent->m_alreadyReadOffset = this->m_alreadyReadOffset;
+    cloneEvent->m_cursor = this->m_cursor;
+    cloneEvent->m_codec = this->m_codec;
+    return cloneEvent;
+}
+
+
 EditWrapper::EditWrapper(Window *window, QWidget *parent)
     : QWidget(parent),
       m_pWindow(window),
@@ -138,7 +188,7 @@ bool EditWrapper::readFile(QByteArray encode)
         m_sFirstEncode = newEncode;
     }
 
-	//QFile file(m_pTextEdit->getFilePath());
+    //QFile file(m_pTextEdit->getFilePath());
     QFile file2(m_pTextEdit->getTruePath());
 
     if (file2.open(QIODevice::ReadOnly)) {
@@ -250,7 +300,7 @@ bool EditWrapper::reloadFileEncode(QByteArray encode)
     //temporarily use '*' to determine whether the text has been modified.
     auto tabname = this->window()->getTabbar()->currentName();
     bool hasFlag = false;
-    if(tabname.size() >0 && "*" == tabname[0]){
+    if (tabname.size() > 0 && "*" == tabname[0]) {
         hasFlag = true;
     }
 
@@ -270,13 +320,13 @@ bool EditWrapper::reloadFileEncode(QByteArray encode)
         }
 
         //不保存,重写载入
-        #if 0
+#if 0
         if (res == 1) {
             bool ok = readFile(encode);
             //if(ok && m_sCurEncode != m_sFirstEncode) m_pTextEdit->setTabbarModified(true);
             return ok;
         }
-        #endif
+#endif
 
         //保存
         if (res == 1) {
@@ -331,7 +381,7 @@ void EditWrapper::reloadModifyFile()
         if (res == 1) {
             //重写加载文件
             readFile();
-            m_bIsTemFile=false;
+            m_bIsTemFile = false;
         }
         //另存
         if (res == 2) {
@@ -347,14 +397,14 @@ void EditWrapper::reloadModifyFile()
             }
             //重写加载文件
             readFile();
-            m_bIsTemFile=false;
+            m_bIsTemFile = false;
         }
 
     } else {
         //重写加载文件
         readFile();
     }
-
+    m_pTextEdit->setBookMarkList(QList<int>());
     QFileInfo fi(m_pTextEdit->getTruePath());
     m_tModifiedDateTime = fi.lastModified();
 
@@ -385,7 +435,7 @@ bool EditWrapper::saveFile()
             // 如果 iconv 转换错误
             if (Outdata.size() == 0) {
                 qWarning() << QString("iconv Encode Transformat from '%1' to '%2' Fail!")
-                              .arg(QString("UTF-8")).arg(m_sCurEncode)
+                           .arg(QString("UTF-8")).arg(m_sCurEncode)
                            << ", start QTextCodec Encode Transformat.";
                 // 使用 QTextCodec 进行转换尝试
                 QTextCodec *codec = QTextCodec::codecForName(m_sCurEncode.toUtf8());
@@ -395,12 +445,12 @@ bool EditWrapper::saveFile()
                     qWarning() << "Both iconv and QTextCodec Encode Transformat Fail!";
                 } else {
                     qWarning() << QString("QTextCodec Encode Transformat from '%1' to '%2' Success!")
-                                  .arg(QString("UTF-8")).arg(m_sCurEncode);
+                               .arg(QString("UTF-8")).arg(m_sCurEncode);
                     Outdata = encodedString;
                 }
             }
 
-            if(Outdata.isEmpty() == false) {
+            if (Outdata.isEmpty() == false) {
                 // 如果新数据为空，不进行文件写入，以降低文件内容损失
                 // 此时如果写入，整个文件将被清空
                 file.write(Outdata);
@@ -500,25 +550,26 @@ bool EditWrapper::saveTemFile(QString qstrDir)
         }
         return ok;
 
-        #if 0
-        }else {
-            file.write(fileContent);
-            QFileDevice::FileError error = file.error();
-            file.close();
-            m_sFirstEncode = m_sCurEncode;
-
-               did save work?
-               only finalize if stream status == OK
-            bool ok = (error == QFileDevice::NoError);
-
-            // update status.
-            if (ok)  updateModifyStatus(true);
-            return ok;
-        }
-        #endif
+#if 0
     } else {
-        return false;
+        file.write(fileContent);
+        QFileDevice::FileError error = file.error();
+        file.close();
+        m_sFirstEncode = m_sCurEncode;
+
+        did save work ?
+        only finalize if stream status == OK
+        bool ok = (error == QFileDevice::NoError);
+
+        // update status.
+        if (ok)  updateModifyStatus(true);
+        return ok;
     }
+#endif
+} else
+{
+    return false;
+}
 }
 
 void EditWrapper::updatePath(const QString &file, QString qstrTruePath)
@@ -548,6 +599,14 @@ bool EditWrapper::isDraftFile()
     return Utils::isDraftFile(m_pTextEdit->getFilePath());
 }
 
+/**
+ * @return 返回当前编辑文件是否为备份文件
+ */
+bool EditWrapper::isBackupFile()
+{
+    return Utils::isBackupFile(m_pTextEdit->getFilePath());
+}
+
 bool EditWrapper::isPlainTextEmpty()
 {
     return m_pTextEdit->document()->isEmpty();
@@ -567,6 +626,7 @@ bool EditWrapper::saveDraftFile()
     dialog.setNameFilter("*.txt");
 
     if (m_pWindow) {
+        m_pWindow = this->window();
         QRegularExpression reg("[^*](.+)");
         QRegularExpressionMatch match = reg.match(m_pWindow->getTabbar()->currentName());
         dialog.selectFile(match.captured(0) + ".txt");
@@ -574,7 +634,7 @@ bool EditWrapper::saveDraftFile()
 
     //this->setUpdatesEnabled(false);
     int mode =  dialog.exec(); // 0表示取消 1保存
-   // this->setUpdatesEnabled(true);
+    // this->setUpdatesEnabled(true);
     hideWarningNotices();
 
     if (mode == 1) {
@@ -600,7 +660,7 @@ bool EditWrapper::saveDraftFile()
         QFile(m_pTextEdit->getFilePath()).remove();
         updateSaveAsFileName(m_pTextEdit->getFilePath(), newFilePath);
         m_pTextEdit->document()->setModified(false);
-         m_bIsTemFile = false;
+        m_bIsTemFile = false;
         return true;
     }
 
@@ -623,7 +683,7 @@ void EditWrapper::checkForReload()
 
     QFileInfo fi(m_pTextEdit->getTruePath());
 
-    QTimer::singleShot(50, [=]() {
+    QTimer::singleShot(50, [ = ]() {
         if (fi.lastModified() == m_tModifiedDateTime || m_pWaringNotices->isVisible()) {
             return;
         }
@@ -695,7 +755,8 @@ void EditWrapper::handleFileLoadFinished(const QByteArray &encode, const QByteAr
 
     bool flag = m_pTextEdit->getReadOnlyPermission();
     if (flag == true) {
-        m_pTextEdit->setReadOnlyPermission(false);
+        // note: 特殊处理，由于需要TextEdit处于可编辑状态追加文件数据，临时设置非只读状态
+        m_pTextEdit->setReadOnly(false);
     }
 
     m_bFileLoading = true;
@@ -704,20 +765,24 @@ void EditWrapper::handleFileLoadFinished(const QByteArray &encode, const QByteAr
 
     //备份显示修改状态
     if (m_bIsTemFile) {
-        // m_bIsTemFile = false;
         updateModifyStatus(true);
     }
 
+    // 判断处理前后对象状态
+    QPointer<QObject> checkPtr(this);
+    // 加载数据
     loadContent(content);
+    if (checkPtr.isNull()) {
+        return;
+    }
+
     //先屏蔽，双字节空字符先按照显示字符编码号处理
     //clearDoubleCharaterEncode();
-
-
     //PerformanceMonitor::openFileFinish(filePath(), QFileInfo(filePath()).size());
 
     m_bFileLoading = false;
     if (flag == true) {
-        m_pTextEdit->setReadOnlyPermission(true);
+        m_pTextEdit->setReadOnly(true);
     }
     if (m_bQuit) {
         return;
@@ -733,8 +798,6 @@ void EditWrapper::handleFileLoadFinished(const QByteArray &encode, const QByteAr
         // 解析未发生错误
         if (!doucment.isNull() && (jsonError.error == QJsonParseError::NoError)) {
             if (doucment.isObject()) {
-                QString temFilePath;
-                QString localPath;
                 // JSON 文档为对象
                 QJsonObject object = doucment.object();  // 转化为对象
 
@@ -770,7 +833,6 @@ void EditWrapper::handleFileLoadFinished(const QByteArray &encode, const QByteAr
     }
     //备份显示修改状态
     if (m_bIsTemFile) {
-        //m_bIsTemFile = false;
         updateModifyStatus(true);
     }
 
@@ -828,6 +890,50 @@ void EditWrapper::OnUpdateHighlighter()
             endBlock = m_pTextEdit->document()->lastBlock();
         }
 
+        // 判断当前文件是否支持高亮处理
+        if (m_pSyntaxHighlighter->definition().isValid()) {
+            // NOTE: 同样需要考虑极限条件下遍历全部文本的情况
+            // 限制最多向上查找512个文本块
+            static int s_MaxFindCount = 512;
+            int maxFindBlockNumber = qMax(0, (beginBlock.blockNumber() - s_MaxFindCount));
+
+            QChar begin = '{', end = '}';
+            int braceDepth = 0;
+            bool foundBrace = false;
+            // 判断是否此文本块为折叠区域起始的文本块，判断'{''}'处理
+            QTextBlock prevBlock = endBlock;
+            while (prevBlock.isValid()
+                   && !foundBrace
+                   && maxFindBlockNumber < prevBlock.blockNumber()) {
+                // 逆序查询文本块数据，查找起始文本块
+                QString text = prevBlock.text();
+                for (int i = text.size() - 1; i >= 0; i--) {
+                    if (text.at(i) == end) {
+                        braceDepth++;
+                    } else if (text.at(i) == begin) {
+                        braceDepth--;
+
+                        // 防止'{'处于展示文本块中间的情况，查询不准确
+                        if (braceDepth < 0) {
+                            braceDepth = 0;
+                        }
+
+                        // 判断是否查找到完整折叠区域
+                        if (0 == braceDepth
+                                && prevBlock.blockNumber() <= beginBlock.blockNumber()) {
+                            foundBrace = true;
+                            break;
+                        }
+                    }
+                }
+
+                prevBlock = prevBlock.previous();
+            }
+
+            // 无论是否查询到折叠区域，均更新起始文本块
+            beginBlock = prevBlock;
+        }
+
         if (!beginBlock.isValid() || !endBlock.isValid()) {
             return;
         }
@@ -875,10 +981,10 @@ void EditWrapper::updateHighlighterAll()
 
 QDateTime EditWrapper::getLastModifiedTime() const
 {
-     return m_tModifiedDateTime;
+    return m_tModifiedDateTime;
 }
 
-void EditWrapper::setLastModifiedTime(const QString& time)
+void EditWrapper::setLastModifiedTime(const QString &time)
 {
     m_tModifiedDateTime = QDateTime::fromString(time);
 }
@@ -907,7 +1013,7 @@ void EditWrapper::setLineNumberShow(bool bIsShow, bool bIsFirstShow)
         //m_pTextEdit->getLeftAreaWidget()->setFixedWidth(leftAreaWidth + lineNumberAreaWidth);
 
     } else if (!bIsShow) {
-       // int lineNumberAreaWidth = m_pTextEdit->getLeftAreaWidget()->m_pLineNumberArea->width();
+        // int lineNumberAreaWidth = m_pTextEdit->getLeftAreaWidget()->m_pLineNumberArea->width();
         //int leftAreaWidth = m_pTextEdit->getLeftAreaWidget()->width();
         m_pTextEdit->getLeftAreaWidget()->m_pLineNumberArea->hide();
         //m_pTextEdit->getLeftAreaWidget()->setFixedWidth(leftAreaWidth - lineNumberAreaWidth);
@@ -962,6 +1068,55 @@ Window *EditWrapper::window()
     return m_pWindow;
 }
 
+void EditWrapper::customEvent(QEvent *e)
+{
+    // 处理解析文件任务，大文件不会在单次事件任务中处理，而是每次读取一部分并将下次任务抛出
+    if (static_cast<QEvent::Type>(ParseFileEvent::EParseFile) == e->type()) {
+        // 中途退出则不继续处理
+        if (m_bQuit) {
+            return;
+        }
+
+        ParseFileEvent *parseEvent = static_cast<ParseFileEvent *>(e);
+        int needReadLen = parseEvent->m_contentData.length() - parseEvent->m_alreadyReadOffset;
+
+        // 调整最大读取长度(单次读取最大长度)
+        if (needReadLen > EReadStepSize) {
+            needReadLen = EReadStepSize;
+        }
+
+        // 转码数据并插入光标位置
+        QByteArray text = parseEvent->m_contentData.mid(parseEvent->m_alreadyReadOffset, needReadLen);
+        QTextCodec::ConverterState state;
+        QString data = parseEvent->m_codec->toUnicode(text.constData(), text.size(), &state);
+        parseEvent->m_cursor.insertText(data);
+
+        // 当前为首次读取
+        if (0 == parseEvent->m_alreadyReadOffset) {
+            QTextCursor firstLineCursor = m_pTextEdit->textCursor();
+            firstLineCursor.movePosition(QTextCursor::Start, QTextCursor::MoveAnchor);
+            m_pTextEdit->setTextCursor(firstLineCursor);
+            //秒开界面语法高亮
+            OnUpdateHighlighter();
+        }
+
+        // 此次读取后的偏移量
+        int curReadOffset = parseEvent->m_alreadyReadOffset + needReadLen;
+
+        // 是否已读取完成
+        if (parseEvent->m_contentData.length() == curReadOffset) {
+            // 异步读取结束
+            m_bAsyncReadFileFinished = true;
+        } else {
+            ParseFileEvent *nextEvent = parseEvent->clone();
+            // 调整已读取偏移位置
+            nextEvent->m_alreadyReadOffset = curReadOffset;
+            // 抛出下一次处理的事件，根据当前是否显示界面调整优先级
+            qApp->postEvent(this, nextEvent, isVisible() ? Qt::NormalEventPriority : (Qt::LowEventPriority - 1));
+        }
+    }
+}
+
 //支持大文本加载 界面不卡顿 秒关闭
 void EditWrapper::loadContent(const QByteArray &strContent)
 {
@@ -974,6 +1129,8 @@ void EditWrapper::loadContent(const QByteArray &strContent)
 
     QApplication::setOverrideCursor(Qt::WaitCursor);
     m_pTextEdit->clear();
+    m_pTextEdit->setReadOnly(true);
+    m_pTextEdit->setLeftAreaUpdateState(TextEdit::FileOpenBegin);
     m_bQuit = false;
     //QTextDocument *doc = m_pTextEdit->document();
     QTextCursor cursor = m_pTextEdit->textCursor();
@@ -984,57 +1141,44 @@ void EditWrapper::loadContent(const QByteArray &strContent)
 
     QTextCodec::ConverterState state;
     QTextCodec *codec = QTextCodec::codecForName("UTF-8");
-    if(nullptr == codec){
-        qInfo()<<"QTextCodec::codecForName return nullptr";
+    if (nullptr == codec) {
+        qInfo() << "QTextCodec::codecForName return nullptr";
         return;
     }
 
-
     int len = strContent.length();
     //初始化显示文本大小
     int InitContentPos = 5 * 1024;
-    //每次读取文件步长
-    int step = 1 * 1024 * 1024;
-    //循环读取次数
-    int cnt = len / step;
-    //文件末尾余数
-    int mod = len % step;
     int max = 40 * 1024 * 1024;
 
     QString data;
 
     if (len > max) {
-        for (int i = 0; i < cnt; i++) {
-            //初始化秒开
-            if (i == 0 && !m_bQuit) {
-                //data = strContent.mid(i * step, step);
-                QByteArray text = strContent.mid(i * step, step);
-                data = codec->toUnicode(text.constData(), text.size(), &state);
-                cursor.insertText(data);
-                QTextCursor firstLineCursor = m_pTextEdit->textCursor();
-                firstLineCursor.movePosition(QTextCursor::Start, QTextCursor::MoveAnchor);
-                m_pTextEdit->setTextCursor(firstLineCursor);
-                //秒开界面语法高亮
-                OnUpdateHighlighter();
-                QApplication::processEvents();
-                continue;
-            }
-            if (!m_bQuit) {
-                //data = strContent.mid(i * step, step);
-                QByteArray text = strContent.mid(i * step, step);
-                data = codec->toUnicode(text.constData(), text.size(), &state);
-                cursor.insertText(data);
-                QApplication::processEvents();
-                if (!m_bQuit && i == cnt - 1 && mod > 0) {
-                    //data = strContent.mid(cnt * step, mod);
-                    QByteArray text = strContent.mid(cnt * step, mod);
-                    data = codec->toUnicode(text.constData(), text.size(), &state);
-                    cursor.insertText(data);
-                    QApplication::processEvents();
-                }
-            }
+        // 当读取大文件时，采用事件队列方式处理
+        ParseFileEvent *parseEvent = new ParseFileEvent;
+        parseEvent->m_contentData = strContent;
+        parseEvent->m_cursor = cursor;
+        parseEvent->m_codec = codec;
+
+        // 将处理事件追加到事件队列
+        qApp->postEvent(this, parseEvent, Qt::HighEventPriority);
+
+        // 使用QPointer判断对象状态
+        QPointer<QObject> checkPtr(this);
+
+        // 程序未退出且读取未完成的情况，持续处理事件
+        m_bAsyncReadFileFinished = false;
+        while (!checkPtr.isNull() && !m_bQuit && !m_bAsyncReadFileFinished) {
+            QApplication::processEvents();
         }
-    } else {
+
+        // 判断当前对象是否已析构，使用processEvents()可能导致在处理事件时，当前编辑控件关闭，
+        // 且在事件循环中进行了析构，导致processEvents()退出时，this对象已析构，无法访问对象成员
+        if (checkPtr.isNull()) {
+            QApplication::restoreOverrideCursor();
+            return;
+        }
+    } else if (len > 0) {
         //初始化秒开
         if (!m_bQuit && len > InitContentPos) {
             //data = strContent.mid(0, InitContentPos);
@@ -1072,6 +1216,8 @@ void EditWrapper::loadContent(const QByteArray &strContent)
     if (m_pBottomBar != nullptr) {
         m_pBottomBar->setChildEnabled(true);
     }
+    m_pTextEdit->setReadOnly(false);
+    m_pTextEdit->setLeftAreaUpdateState(TextEdit::FileOpenEnd);
     QApplication::restoreOverrideCursor();
 }
 
@@ -1086,3 +1232,5 @@ void EditWrapper::clearDoubleCharaterEncode()
         emit sigClearDoubleCharaterEncode();
     }
 }
+
+
