@@ -39,7 +39,7 @@ QByteArray DetectCode::GetFileEncodingFormat(QString filepath, QByteArray conten
     QByteArray ucharDetectdRet;
     QByteArrayList icuDetectRetList;
     QByteArray detectRet;
-    float chardetconfidence = 0;
+    float chardetconfidence = 0.0f;
 
     /* chardet识别编码 */
     QString str(content);
@@ -54,7 +54,7 @@ QByteArray DetectCode::GetFileEncodingFormat(QString filepath, QByteArray conten
     ucharDetectdRet = charDetectedResult.toLatin1();
 
     /* uchardet识别编码 */
-    if (ucharDetectdRet == "unknown" || ucharDetectdRet == "???" || ucharDetectdRet.isEmpty()) {
+    if (ucharDetectdRet.contains("unknown") || ucharDetectdRet.contains("???") || ucharDetectdRet.isEmpty()) {
        ucharDetectdRet = DetectCode::UchardetCode(filepath);
     }
 
@@ -62,7 +62,7 @@ QByteArray DetectCode::GetFileEncodingFormat(QString filepath, QByteArray conten
     icuDetectTextEncoding(filepath, icuDetectRetList);
     detectRet = selectCoding(ucharDetectdRet, icuDetectRetList);
 
-    if(detectRet == "ASCII" || detectRet.isEmpty()) {
+    if(detectRet.contains("ASCII") || detectRet.isEmpty()) {
         detectRet = "UTF-8";
     }
 
@@ -126,12 +126,15 @@ void DetectCode::icuDetectTextEncoding(const QString &filePath, QByteArrayList &
     char *buffer = new char[iBuffSize];
     memset(buffer, 0, iBuffSize);
 
+    int readed=0;
     while (!feof(file)) {
         int32_t len = fread(buffer, 1, iBuffSize, file);
-        if (detected == nullptr) {
-            if (!detectTextEncoding(buffer, len, &detected, listDetectRet)) {
-                break;
-            }
+        readed+=len;
+        if(readed>1*1024*1024){
+            break;
+        }
+        if (!detectTextEncoding(buffer, len, &detected, listDetectRet)) {
+            break;
         }
     }
 
@@ -169,20 +172,21 @@ bool DetectCode::detectTextEncoding(const char *data, size_t len, char **detecte
     }
 
     if (matchCount >= 3) {
-        *detected = strdup(ucsdet_getName(csm[0], &status));
-        listDetectRet << QByteArray(*detected);
-        *detected = strdup(ucsdet_getName(csm[1], &status));
-        listDetectRet << QByteArray(*detected);
-        *detected = strdup(ucsdet_getName(csm[2], &status));
-        listDetectRet << QByteArray(*detected);
-        if (status != U_ZERO_ERROR) {
-            return false;
+        for(int i=0;i<3;i++){
+            auto str = ucsdet_getName(csm[i], &status);
+            if (status != U_ZERO_ERROR) {
+                return false;
+            }
+            listDetectRet << QByteArray(str);
         }
+
+
     } else if (matchCount > 0) {
-        *detected = strdup(ucsdet_getName(csm[0], &status));
-        listDetectRet << QByteArray(*detected);
+        auto str = ucsdet_getName(csm[0], &status);
+        listDetectRet << QByteArray(str);
     }
 
+
     ucsdet_close(csd);
 
     return true;
