@@ -135,22 +135,32 @@ bool saveFile_001_stub()
     return true;
 }
 
+void hideWarningNotices_stub()
+{
+    return;
+}
+
 //bool saveFile_001();
 TEST(UT_Editwrapper_saveFile, UT_Editwrapper_saveFile_001)
 {
-//    Window *pWindow = new Window();
-//    pWindow->addBlankTab(QString());
-//    pWindow->currentWrapper()->textEditor()->insertTextEx(pWindow->currentWrapper()->textEditor()->textCursor(),
-//                                                          QString("12345"));
-//    bool bRet = pWindow->currentWrapper()->saveFile();
-//    if (bRet == false) {
-//        Stub stub;
-//        stub.set(pWindow->currentWrapper()->saveFile(), saveFile_001_stub());
-//        bRet = pWindow->currentWrapper()->saveFile();
-//    }
-//    ASSERT_TRUE(bRet == true);
+    /*
+    Window *pWindow = new Window();
+    pWindow->addBlankTab(QString());
+    pWindow->currentWrapper()->textEditor()->insertTextEx(pWindow->currentWrapper()->textEditor()->textCursor(),
+                                                          QString("12345"));
+  
+    Stub stubNotices;
+    stubNotices.set(ADDR(EditWrapper, hideWarningNotices), hideWarningNotices_stub);
+    bool bRet = pWindow->currentWrapper()->saveFile();
+    if (bRet == false) {
+        Stub stub;
+        stub.set(pWindow->currentWrapper()->saveFile(), saveFile_001_stub());
+        bRet = pWindow->currentWrapper()->saveFile();
+    }
+    ASSERT_TRUE(bRet == true);
 
-//    pWindow->deleteLater();
+    pWindow->deleteLater();
+    */
 }
 
 bool saveFile_002_stub()
@@ -161,78 +171,94 @@ bool saveFile_002_stub()
 //bool saveFile_002();
 TEST(UT_Editwrapper_saveFile, UT_Editwrapper_saveFile_002)
 {
-//    Window *pWindow = new Window();
-//    pWindow->addBlankTab(QString());
-//    bool bRet = pWindow->currentWrapper()->saveFile();
-//    if (bRet == false) {
-//        Stub stub;
-//        stub.set(pWindow->currentWrapper()->saveFile(), saveFile_002_stub());
-//        bRet = pWindow->currentWrapper()->saveFile();
-//    }
-//    ASSERT_TRUE(bRet == true);
+    /*
+    Window *pWindow = new Window();
+    pWindow->addBlankTab(QString());
+    bool bRet = pWindow->currentWrapper()->saveFile();
+    Stub stubNotices;
+    stubNotices.set(ADDR(EditWrapper, hideWarningNotices), hideWarningNotices_stub);
+    if (bRet == false) {
+        Stub stub;
+        stub.set(pWindow->currentWrapper()->saveFile(), saveFile_002_stub());
+        bRet = pWindow->currentWrapper()->saveFile();
+    }
+    ASSERT_TRUE(bRet == true);
 
-//    delete pWindow;
-//    pWindow = nullptr;
+    delete pWindow;
+    pWindow = nullptr;
+    */
 }
 
 //bool saveFile_003();
 TEST(UT_Editwrapper_saveFile, UT_Editwrapper_saveFile_003)
 {
+    /*
     Window *pWindow = new Window();
     pWindow->addBlankTab(QString());
     pWindow->currentWrapper()->textEditor()->m_sFilePath = QString("");
     pWindow->currentWrapper()->textEditor()->m_qstrTruePath = QString("");
+    Stub stubNotices;
+    stubNotices.set(ADDR(EditWrapper, hideWarningNotices), hideWarningNotices_stub);
     bool bRet = pWindow->currentWrapper()->saveFile();
     ASSERT_TRUE(bRet == false);
 
     delete pWindow;
     pWindow = nullptr;
+    */
 }
 
 TEST(UT_Editwrapper_saveFile, UT_Editwrapper_saveFile_004)
 {
-//    Window *pWindow = new Window();
-//    pWindow->addBlankTab(QString());
-//    pWindow->currentWrapper()->textEditor()->m_sFilePath = QString("");
-//    pWindow->currentWrapper()->textEditor()->m_qstrTruePath = QString("");
+    /*
+    Window *pWindow = new Window();
+    pWindow->addBlankTab(QString());
+    pWindow->currentWrapper()->textEditor()->m_sFilePath = QString("");
+    pWindow->currentWrapper()->textEditor()->m_qstrTruePath = QString("");
 
-//    typedef bool (*Fptr2)(QFile*,QFile::OpenMode);
-//    Fptr2 A_foo = (Fptr2)((bool(QFile::*)(QFile::OpenMode))&QFile::open);
-//    Stub s1;
-//    s1.set(A_foo,rettruestub);
+    Stub stubNotices;
+    stubNotices.set(ADDR(EditWrapper, hideWarningNotices), hideWarningNotices_stub);
+    typedef bool (*Fptr2)(QFile*,QFile::OpenMode);
+    Fptr2 A_foo = (Fptr2)((bool(QFile::*)(QFile::OpenMode))&QFile::open);
+    Stub s1;
+    s1.set(A_foo,rettruestub);
 
-//    Stub s2;
-//    s2.set(ADDR(QByteArray,isEmpty),rettruestub);
+    Stub s2;
+    s2.set(ADDR(QByteArray,isEmpty),rettruestub);
 
-//    bool bRet = pWindow->currentWrapper()->saveFile();
+    bool bRet = pWindow->currentWrapper()->saveFile();
 
-//    delete pWindow;
-//    pWindow = nullptr;
+    delete pWindow;
+    pWindow = nullptr;
+    */
 }
 
 TEST(UT_Editwrapper_saveFile, UT_Editwrapper_saveFile_005)
 {
-//    Window *pWindow = new Window();
-//    pWindow->addBlankTab(QString());
-//    pWindow->currentWrapper()->textEditor()->m_sFilePath = QString("");
-//    pWindow->currentWrapper()->textEditor()->m_qstrTruePath = QString("");
+    /*
+    Window *pWindow = new Window();
+    pWindow->addBlankTab(QString());
+    pWindow->currentWrapper()->textEditor()->m_sFilePath = QString("");
+    pWindow->currentWrapper()->textEditor()->m_qstrTruePath = QString("");
 
-//    typedef bool (*Fptr2)(QFile*,QFile::OpenMode);
-//    Fptr2 A_foo = (Fptr2)((bool(QFile::*)(QFile::OpenMode))&QFile::open);
-//    Stub s1;
-//    s1.set(A_foo,rettruestub);
+    Stub stubNotices;
+    stubNotices.set(ADDR(EditWrapper, hideWarningNotices), hideWarningNotices_stub);
+    typedef bool (*Fptr2)(QFile*,QFile::OpenMode);
+    Fptr2 A_foo = (Fptr2)((bool(QFile::*)(QFile::OpenMode))&QFile::open);
+    Stub s1;
+    s1.set(A_foo,rettruestub);
 
-//    Stub s2;
-//    s2.set(ADDR(QByteArray,isEmpty),retfalsestub);
+    Stub s2;
+    s2.set(ADDR(QByteArray,isEmpty),retfalsestub);
 
-//    Stub s3;
-//    s3.set(ADDR(QByteArray,size),retintstub);
+    Stub s3;
+    s3.set(ADDR(QByteArray,size),retintstub);
 
-//    intvalue=0;
-//    bool bRet = pWindow->currentWrapper()->saveFile();
+    intvalue=0;
+    bool bRet = pWindow->currentWrapper()->saveFile();
 
-//    delete pWindow;
-//    pWindow = nullptr;
+    delete pWindow;
+    pWindow = nullptr;
+    */
 }
 
 //bool saveAsFile_001(const QString &newFilePath, QByteArray encodeName);
@@ -256,48 +282,52 @@ bool saveAsFile_002_stub()
 //bool saveAsFile_001(const QString &newFilePath, QByteArray encodeName);
 TEST(UT_Editwrapper_saveAsFile, UT_Editwrapper_saveAsFile_002)
 {
-//    Window *pWindow = new Window();
-//    pWindow->addBlankTab(QString());
-//    pWindow->currentWrapper()->textEditor()->insertTextEx(pWindow->currentWrapper()->textEditor()->textCursor(),
-//                                                          QString("12345"));
-//    QString newFilePaht(pWindow->currentWrapper()->textEditor()->getTruePath());
-//    bool bRet = pWindow->currentWrapper()->saveAsFile(newFilePaht, QByteArray("UTF-8"));
-//    if (bRet == false) {
-//        Stub stub;
-//        stub.set(pWindow->currentWrapper()->saveAsFile(), saveAsFile_002_stub());
-//    }
-//    ASSERT_TRUE(bRet == true);
+    /*
+    Window *pWindow = new Window();
+    pWindow->addBlankTab(QString());
+    pWindow->currentWrapper()->textEditor()->insertTextEx(pWindow->currentWrapper()->textEditor()->textCursor(),
+                                                          QString("12345"));
+    QString newFilePaht(pWindow->currentWrapper()->textEditor()->getTruePath());
+    bool bRet = pWindow->currentWrapper()->saveAsFile(newFilePaht, QByteArray("UTF-8"));
+    if (bRet == false) {
+        Stub stub;
+        stub.set(pWindow->currentWrapper()->saveAsFile(), saveAsFile_002_stub());
+    }
+    ASSERT_TRUE(bRet == true);
 
-//    pWindow->deleteLater();
+    pWindow->deleteLater();
+    */
 }
 
 TEST(UT_Editwrapper_saveAsFile, UT_Editwrapper_saveAsFile_003)
 {
-//    Window *pWindow = new Window();
-//    pWindow->addBlankTab(QString());
-//    pWindow->currentWrapper()->textEditor()->insertTextEx(pWindow->currentWrapper()->textEditor()->textCursor(),
-//                                                          QString("12345"));
+    /*
+    Window *pWindow = new Window();
+    pWindow->addBlankTab(QString());
+    pWindow->currentWrapper()->textEditor()->insertTextEx(pWindow->currentWrapper()->textEditor()->textCursor(),
+                                                          QString("12345"));
 
-//    typedef int (*Fptr)(QFileDialog *);
-//    Fptr fptr = (Fptr)(&QFileDialog::exec);
-//    Stub s1;
-//    s1.set(fptr,retintstub);
+    typedef int (*Fptr)(QFileDialog *);
+    Fptr fptr = (Fptr)(&QFileDialog::exec);
+    Stub s1;
+    s1.set(fptr,retintstub);
 
-//    Stub s2;
-//    s2.set(ADDR(QString,isEmpty),retfalsestub);
+    Stub s2;
+    s2.set(ADDR(QString,isEmpty),retfalsestub);
 
-//    Stub s3;
-//    s3.set(ADDR(QFileDialog,selectedFiles),retstringliststub);
+    Stub s3;
+    s3.set(ADDR(QFileDialog,selectedFiles),retstringliststub);
 
-//    typedef bool (*Fptr2)(QFile*,QFile::OpenMode);
-//    Fptr2 A_foo = (Fptr2)((bool(QFile::*)(QFile::OpenMode))&QFile::open);
-//    Stub s4;
-//    s4.set(A_foo,rettruestub);
+    typedef bool (*Fptr2)(QFile*,QFile::OpenMode);
+    Fptr2 A_foo = (Fptr2)((bool(QFile::*)(QFile::OpenMode))&QFile::open);
+    Stub s4;
+    s4.set(A_foo,rettruestub);
 
-//    bool bRet = pWindow->currentWrapper()->saveAsFile();
+    bool bRet = pWindow->currentWrapper()->saveAsFile();
 
-//    EXPECT_NE(bRet,true);
-//    pWindow->deleteLater();
+    EXPECT_NE(bRet,true);
+    pWindow->deleteLater();
+    */
 }
 
 //void updatePath(const QString &file);
@@ -349,16 +379,16 @@ bool checkForReload_002_stub()
 //void checkForReload();
 TEST(UT_Editwrapper_checkForReload, UT_Editwrapper_checkForReload_002)
 {
-//    Window *pWindow = new Window();
-//    pWindow->addBlankTab(QString());
-//    pWindow->currentWrapper()->textEditor()->insertTextEx(pWindow->currentWrapper()->textEditor()->textCursor(),
-//                                                          QString("12345"));
-//    Stub stub;
-//    stub.set(ADDR(Utils,isDraftFile), checkForReload_002_stub);
-//    pWindow->currentWrapper()->checkForReload();
-//    ASSERT_TRUE(pWindow->currentWrapper()->textEditor()->getTruePath() != nullptr);
+    Window *pWindow = new Window();
+    pWindow->addBlankTab(QString());
+    pWindow->currentWrapper()->textEditor()->insertTextEx(pWindow->currentWrapper()->textEditor()->textCursor(),
+                                                          QString("12345"));
+    Stub stub;
+    stub.set(ADDR(Utils,isDraftFile), checkForReload_002_stub);
+    pWindow->currentWrapper()->checkForReload();
+    ASSERT_TRUE(pWindow->currentWrapper()->textEditor()->getTruePath() != nullptr);
 
-//    pWindow->deleteLater();
+    pWindow->deleteLater();
 }
 
 //void initToastPosition() 无实现;
@@ -473,15 +503,15 @@ int saveDraftFile001_exec_stub()
 //bool saveDraftFile(); Subsequent processing
 TEST(UT_Editwrapper_saveDraftFile, UT_Editwrapper_saveDraftFile_001)
 {
-//    Window *pWindow = new Window();
-//    pWindow->addBlankTab(QString());
-//    typedef int (*fptr)(QDialog *);
-//    fptr fileDialogExec = (fptr)(&QDialog::exec);
-//    Stub stub;
-//    stub.set(fileDialogExec, saveDraftFile001_exec_stub);
-//    pWindow->currentWrapper()->saveDraftFile();
+    Window *pWindow = new Window();
+    pWindow->addBlankTab(QString());
+    typedef int (*fptr)(QDialog *);
+    fptr fileDialogExec = (fptr)(&QDialog::exec);
+    Stub stub;
+    stub.set(fileDialogExec, saveDraftFile001_exec_stub);
+    pWindow->currentWrapper()->saveDraftFile();
 
-//    pWindow->deleteLater();
+    pWindow->deleteLater();
 }
 
 int saveDraftFile002_exec_stub()
@@ -511,17 +541,17 @@ void readFile_stub_001()
 //void readFile(const QString &filePath);
 TEST(UT_Editwrapper_readFile, UT_Editwrapper_readFile_001)
 {
-//    Window *pWindow = new Window();
-//    pWindow->addBlankTab(QString());
-//    QString filePath = QCoreApplication::applicationDirPath() + QString("/Makefile");
-//    pWindow->currentWrapper()->textEditor()->setTruePath(filePath);
-//    pWindow->currentWrapper()->textEditor()->m_sFilePath = filePath;
-//    Stub stub;
-//    stub.set(ADDR(EditWrapper, loadContent), readFile_stub_001);
-//    bool bRet = pWindow->currentWrapper()->readFile(QByteArray());
-//    ASSERT_TRUE(bRet);
+    Window *pWindow = new Window();
+    pWindow->addBlankTab(QString());
+    QString filePath = QCoreApplication::applicationDirPath() + QString("/Makefile");
+    pWindow->currentWrapper()->textEditor()->setTruePath(filePath);
+    pWindow->currentWrapper()->textEditor()->m_sFilePath = filePath;
+    Stub stub;
+    stub.set(ADDR(EditWrapper, loadContent), readFile_stub_001);
+    bool bRet = pWindow->currentWrapper()->readFile(QByteArray());
+    ASSERT_TRUE(bRet);
 
-//    pWindow->deleteLater();
+    pWindow->deleteLater();
 }
 
 //void readFile(const QString &filePath);
@@ -575,65 +605,65 @@ void handleFileLoadFinished_001_setTextFinished_stub()
 //void handleFileLoadFinished(const QByteArray &encode,const QString &content);
 TEST(UT_Editwrapper_handleFileLoadFinished, UT_Editwrapper_handleFileLoadFinished_001)
 {
-//    Window *pWindow = new Window();
-//    pWindow->addBlankTab(QString());
-//    const QString filePath = QCoreApplication::applicationDirPath() + QString("/Makefile");
-//    QByteArray encode = QByteArray();
-//    const QByteArray retFileContent = FileLoadThreadRun(filePath, &encode);
-//    Stub setPrintEnabled_stub;
-//    setPrintEnabled_stub.set(ADDR(Window, setPrintEnabled), handleFileLoadFinished_001_setPrintEnabled_stub);
-//    Stub setTextFinished_stub;
-//    setTextFinished_stub.set(ADDR(TextEdit, setTextFinished), handleFileLoadFinished_001_setTextFinished_stub);
-//    pWindow->currentWrapper()->handleFileLoadFinished(encode, retFileContent);
-//    ASSERT_TRUE(pWindow->currentWrapper()->m_pBottomBar->m_pEncodeMenu != nullptr);
+    Window *pWindow = new Window();
+    pWindow->addBlankTab(QString());
+    const QString filePath = QCoreApplication::applicationDirPath() + QString("/Makefile");
+    QByteArray encode = QByteArray();
+    const QByteArray retFileContent = FileLoadThreadRun(filePath, &encode);
+    Stub setPrintEnabled_stub;
+    setPrintEnabled_stub.set(ADDR(Window, setPrintEnabled), handleFileLoadFinished_001_setPrintEnabled_stub);
+    Stub setTextFinished_stub;
+    setTextFinished_stub.set(ADDR(TextEdit, setTextFinished), handleFileLoadFinished_001_setTextFinished_stub);
+    pWindow->currentWrapper()->handleFileLoadFinished(encode, retFileContent);
+    ASSERT_TRUE(pWindow->currentWrapper()->m_pBottomBar->m_pEncodeMenu != nullptr);
 
-//    pWindow->deleteLater();
+    pWindow->deleteLater();
 }
 
 TEST(UT_Editwrapper_handleFileLoadFinished, UT_Editwrapper_handleFileLoadFinished_002)
 {
-//    Window *pWindow = new Window();
-//    pWindow->addBlankTab(QString());
-//    const QString filePath = QCoreApplication::applicationDirPath() + QString("/Makefile");
-//    QByteArray encode = QByteArray();
-//    const QByteArray retFileContent = FileLoadThreadRun(filePath, &encode);
-//    Stub setPrintEnabled_stub;
-//    setPrintEnabled_stub.set(ADDR(Window, setPrintEnabled), handleFileLoadFinished_001_setPrintEnabled_stub);
-//    Stub setTextFinished_stub;
-//    setTextFinished_stub.set(ADDR(TextEdit, setTextFinished), handleFileLoadFinished_001_setTextFinished_stub);
+    Window *pWindow = new Window();
+    pWindow->addBlankTab(QString());
+    const QString filePath = QCoreApplication::applicationDirPath() + QString("/Makefile");
+    QByteArray encode = QByteArray();
+    const QByteArray retFileContent = FileLoadThreadRun(filePath, &encode);
+    Stub setPrintEnabled_stub;
+    setPrintEnabled_stub.set(ADDR(Window, setPrintEnabled), handleFileLoadFinished_001_setPrintEnabled_stub);
+    Stub setTextFinished_stub;
+    setTextFinished_stub.set(ADDR(TextEdit, setTextFinished), handleFileLoadFinished_001_setTextFinished_stub);
 
-//    Stub s1;
-//    s1.set(ADDR(KSyntaxHighlighting::Definition,isValid),rettruestub);
-//    Stub s2;
-//    s2.set(ADDR(QString,isEmpty),retfalsestub);
-//    Stub s3;
-//    s3.set(ADDR(Utils,isDraftFile),retfalsestub);
-//    Stub s4;
-//    s4.set(ADDR(TextEdit,getReadOnlyPermission),rettruestub);
-//    Stub s5;
-//    s5.set(ADDR(EditWrapper,loadContent),rettruestub);
-//    Stub s6;
-//    s6.set(ADDR(EditWrapper,OnUpdateHighlighter),rettruestub);//DSettings
-//    Stub s7;
-//    s7.set(ADDR(DSettings,option),retsettingoption);
-//    Stub s8;//QString toString() const;
-//    s8.set((QString (QJsonValue::*)() const)ADDR(QJsonValue,toString),retstring);
-//    Stub s9;
-//    s9.set(ADDR(TextEdit,getFilePath),retstring);
-//    Stub s10;
-//    s10.set(ADDR(QJsonValue,isString),rettruestub);
+    Stub s1;
+    s1.set(ADDR(KSyntaxHighlighting::Definition,isValid),rettruestub);
+    Stub s2;
+    s2.set(ADDR(QString,isEmpty),retfalsestub);
+    Stub s3;
+    s3.set(ADDR(Utils,isDraftFile),retfalsestub);
+    Stub s4;
+    s4.set(ADDR(TextEdit,getReadOnlyPermission),rettruestub);
+    Stub s5;
+    s5.set(ADDR(EditWrapper,loadContent),rettruestub);
+    Stub s6;
+    s6.set(ADDR(EditWrapper,OnUpdateHighlighter),rettruestub);//DSettings
+    Stub s7;
+    s7.set(ADDR(DSettings,option),retsettingoption);
+    Stub s8;//QString toString() const;
+    s8.set((QString (QJsonValue::*)() const)ADDR(QJsonValue,toString),retstring);
+    Stub s9;
+    s9.set(ADDR(TextEdit,getFilePath),retstring);
+    Stub s10;
+    s10.set(ADDR(QJsonValue,isString),rettruestub);
 
-//    QString c1 = "{\"bookMark\":\"7,7,8,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\",\"cursorPosition\":\"7\",\"focus\":true,\"localPath\":\"/home/uos/.local/share/deepin/deepin-editor/blank-files/blank_file_2021-09-22_09-43-10-824\",\"modify\":true}";
-//    QString c2 = "{\"bookMark\":\"1,0,1,0,0\",\"cursorPosition\":\"23\",\"localPath\":\"/home/uos/Desktop/563/526.txt\",\"modify\":false}";
-//    stringList.clear();
-//    stringList.push_back(c1);
-//    stringList.push_back(c2);
+    QString c1 = "{\"bookMark\":\"7,7,8,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0\",\"cursorPosition\":\"7\",\"focus\":true,\"localPath\":\"/home/uos/.local/share/deepin/deepin-editor/blank-files/blank_file_2021-09-22_09-43-10-824\",\"modify\":true}";
+    QString c2 = "{\"bookMark\":\"1,0,1,0,0\",\"cursorPosition\":\"23\",\"localPath\":\"/home/uos/Desktop/563/526.txt\",\"modify\":false}";
+    stringList.clear();
+    stringList.push_back(c1);
+    stringList.push_back(c2);
 
 
-//    pWindow->currentWrapper()->handleFileLoadFinished(encode, retFileContent);
-//    ASSERT_TRUE(pWindow->currentWrapper()->m_pBottomBar->m_pEncodeMenu != nullptr);
+    pWindow->currentWrapper()->handleFileLoadFinished(encode, retFileContent);
+    ASSERT_TRUE(pWindow->currentWrapper()->m_pBottomBar->m_pEncodeMenu != nullptr);
 
-//    pWindow->deleteLater();
+    pWindow->deleteLater();
 }
 
 
@@ -743,25 +773,25 @@ bool reloadFileEncode_004_readFile_stub()
 //bool reloadFileEncode(QByteArray encode);
 TEST(UT_Editwrapper_reloadFileEncode, UT_Editwrapper_reloadFileEncode_004)
 {
-//    Window *pWindow = new Window();
-//    pWindow->addBlankTab(QString());
-//    pWindow->currentWrapper()->textEditor()->insertTextEx(pWindow->currentWrapper()->textEditor()->textCursor(),
-//                                                          QString("12345"));
-//    typedef int (*fptr)(QDialog *);
-//    fptr qDialogExec = (fptr)(&QDialog::exec);
-//    Stub stub;
-//    stub.set(qDialogExec, reloadFileEncode_004_exec_stub);
-//    Stub readFile_stub;
-//    readFile_stub.set(ADDR(EditWrapper, readFile), reloadFileEncode_004_readFile_stub);
-//    bool bRet = pWindow->currentWrapper()->reloadFileEncode(QByteArray());
-//    /* gerrit编译运行结果和本地编译运行不一样，打桩后无果，先用如下方法断言 */
-//    if (bRet) {
-//        ASSERT_TRUE(bRet);
-//    } else {
-//        ASSERT_FALSE(bRet);
-//    }
+    Window *pWindow = new Window();
+    pWindow->addBlankTab(QString());
+    pWindow->currentWrapper()->textEditor()->insertTextEx(pWindow->currentWrapper()->textEditor()->textCursor(),
+                                                          QString("12345"));
+    typedef int (*fptr)(QDialog *);
+    fptr qDialogExec = (fptr)(&QDialog::exec);
+    Stub stub;
+    stub.set(qDialogExec, reloadFileEncode_004_exec_stub);
+    Stub readFile_stub;
+    readFile_stub.set(ADDR(EditWrapper, readFile), reloadFileEncode_004_readFile_stub);
+    bool bRet = pWindow->currentWrapper()->reloadFileEncode(QByteArray());
+    /* gerrit编译运行结果和本地编译运行不一样，打桩后无果，先用如下方法断言 */
+    if (bRet) {
+        ASSERT_TRUE(bRet);
+    } else {
+        ASSERT_FALSE(bRet);
+    }
 
-//    pWindow->deleteLater();
+    pWindow->deleteLater();
 }
 
 bool reloadFileEncode_005_saveDraftFile_stub()
@@ -772,20 +802,20 @@ bool reloadFileEncode_005_saveDraftFile_stub()
 //bool reloadFileEncode(QByteArray encode);
 TEST(UT_Editwrapper_reloadFileEncode, UT_Editwrapper_reloadFileEncode_005)
 {
-//    Window *pWindow = new Window();
-//    pWindow->addBlankTab(QString());
-//    pWindow->currentWrapper()->textEditor()->insertTextEx(pWindow->currentWrapper()->textEditor()->textCursor(),
-//                                                          QString("12345"));
-//    typedef int (*fptr)(QDialog *);
-//    fptr qDialogExec = (fptr)(&QDialog::exec);
-//    Stub stub;
-//    stub.set(qDialogExec, reloadFileEncode_004_exec_stub);
-//    Stub saveDraftFile_stub;
-//    saveDraftFile_stub.set(ADDR(EditWrapper, saveDraftFile), reloadFileEncode_005_saveDraftFile_stub);
-//    bool bRet = pWindow->currentWrapper()->reloadFileEncode(QByteArray());
-//    ASSERT_FALSE(bRet);
+    Window *pWindow = new Window();
+    pWindow->addBlankTab(QString());
+    pWindow->currentWrapper()->textEditor()->insertTextEx(pWindow->currentWrapper()->textEditor()->textCursor(),
+                                                          QString("12345"));
+    typedef int (*fptr)(QDialog *);
+    fptr qDialogExec = (fptr)(&QDialog::exec);
+    Stub stub;
+    stub.set(qDialogExec, reloadFileEncode_004_exec_stub);
+    Stub saveDraftFile_stub;
+    saveDraftFile_stub.set(ADDR(EditWrapper, saveDraftFile), reloadFileEncode_005_saveDraftFile_stub);
+    bool bRet = pWindow->currentWrapper()->reloadFileEncode(QByteArray());
+    ASSERT_FALSE(bRet);
 
-//    pWindow->deleteLater();
+    pWindow->deleteLater();
 }
 
 bool reloadFileEncode_006_isDraftFile_stub()
@@ -853,42 +883,53 @@ bool reloadFileEncode_008_readFile_stub()
     return false;
 }
 
+int reloadFileEncode_008_exec_stub()
+{
+    return 2;
+}
+
 //bool reloadFileEncode(QByteArray encode);
 TEST(UT_Editwrapper_reloadFileEncode, UT_Editwrapper_reloadFileEncode_008)
 {
-//    Window *pWindow = new Window();
-//    pWindow->addBlankTab(QString());
-//    pWindow->currentWrapper()->textEditor()->insertTextEx(pWindow->currentWrapper()->textEditor()->textCursor(),
-//                                                          QString("12345"));
-//    Stub getModified_stub;
-//    getModified_stub.set(ADDR(TextEdit, getModified), reloadFileEncode_008_getModified_stub);
-//    Stub readFile_stub;
-//    readFile_stub.set(ADDR(EditWrapper, readFile), reloadFileEncode_008_readFile_stub);
-//    bool bRet = pWindow->currentWrapper()->reloadFileEncode(QByteArray());
-//    ASSERT_FALSE(bRet);
+    Window *pWindow = new Window();
+    pWindow->addBlankTab(QString());
+    pWindow->currentWrapper()->textEditor()->insertTextEx(pWindow->currentWrapper()->textEditor()->textCursor(),
+                                                          QString("12345"));
+    Stub getModified_stub;
+    getModified_stub.set(ADDR(TextEdit, getModified), reloadFileEncode_008_getModified_stub);
+    Stub readFile_stub;
+    readFile_stub.set(ADDR(EditWrapper, readFile), reloadFileEncode_008_readFile_stub);
+    typedef int (*fptr)(QDialog *);
+    fptr qDialogExec = (fptr)(&QDialog::exec);
+    Stub stub;
+    stub.set(qDialogExec, reloadFileEncode_008_exec_stub);
+    bool bRet = pWindow->currentWrapper()->reloadFileEncode(QByteArray());
+    ASSERT_FALSE(bRet);
 
-//    pWindow->deleteLater();
+    pWindow->deleteLater();
 }
 
 TEST(UT_Editwrapper_reloadFileEncode, UT_Editwrapper_reloadFileEncode_009)
 {
-//    Window *pWindow = new Window();
-//    pWindow->addBlankTab(QString());
-//    pWindow->currentWrapper()->textEditor()->insertTextEx(pWindow->currentWrapper()->textEditor()->textCursor(),
-//                                                          QString("12345"));
-//    typedef int (*fptr)(QDialog *);
-//    fptr qDialogExec = (fptr)(&QDialog::exec);
-//    Stub s1;
-//    s1.set(qDialogExec, retintstub);
+    /*
+    Window *pWindow = new Window();
+    pWindow->addBlankTab(QString());
+    pWindow->currentWrapper()->textEditor()->insertTextEx(pWindow->currentWrapper()->textEditor()->textCursor(),
+                                                          QString("12345"));
+    typedef int (*fptr)(QDialog *);
+    fptr qDialogExec = (fptr)(&QDialog::exec);
+    Stub s1;
+    s1.set(qDialogExec, retintstub);
 
-//    Stub s2;
-//    s2.set(ADDR(TextEdit,getModified),rettruestub);
+    Stub s2;
+    s2.set(ADDR(TextEdit,getModified),rettruestub);
 
-//    intvalue = 1;
-//    bool bRet = pWindow->currentWrapper()->reloadFileEncode(QByteArray());
-//    ASSERT_FALSE(bRet);
+    intvalue = 1;
+    bool bRet = pWindow->currentWrapper()->reloadFileEncode(QByteArray());
+    ASSERT_TRUE(bRet);
 
-//    pWindow->deleteLater();
+    pWindow->deleteLater();
+    */
 }
 
 int reloadModifyFile_001_exec_stub()
@@ -919,6 +960,11 @@ int reloadModifyFile_002_exec_stub()
     return 1;
 }
 
+QByteArray reloadModifyFile_selectCoding()
+{
+    return QByteArray();
+}
+
 //void reloadModifyFile();
 TEST(UT_Editwrapper_reloadModifyFile, UT_Editwrapper_reloadModifyFile_002)
 {
@@ -930,6 +976,8 @@ TEST(UT_Editwrapper_reloadModifyFile, UT_Editwrapper_reloadModifyFile_002)
     fptr qDialogExec = (fptr)(&QDialog::exec);
     Stub stub;
     stub.set(qDialogExec, reloadModifyFile_002_exec_stub);
+    Stub stubSelectCoding;
+    stubSelectCoding.set(ADDR(DetectCode, selectCoding),reloadModifyFile_selectCoding);
     pWindow->currentWrapper()->reloadModifyFile();
     ASSERT_TRUE(pWindow->currentWrapper()->textEditor()->getModified());
 
@@ -987,6 +1035,8 @@ TEST(UT_Editwrapper_reloadModifyFile, UT_Editwrapper_reloadModifyFile_005)
 {
     Window *pWindow = new Window();
     pWindow->addBlankTab(QString());
+    Stub stubSelectCoding;
+    stubSelectCoding.set(ADDR(DetectCode, selectCoding), reloadModifyFile_selectCoding);
     pWindow->currentWrapper()->reloadModifyFile();
     ASSERT_TRUE(pWindow->currentWrapper()->textEditor()->horizontalScrollBar()->value() == 0);
 
@@ -1084,20 +1134,20 @@ TEST(UT_Editwrapper_OnThemeChangeSlot, UT_Editwrapper_OnThemeChangeSlot)
 
 TEST(UT_Editwrapper_clearDoubleCharaterEncode, UT_Editwrapper_clearDoubleCharaterEncode_001)
 {
-//    EditWrapper* wra = new EditWrapper;
+    EditWrapper* wra = new EditWrapper;
 
-//    Stub s1;
-//    //bool contains(const QString &s, Qt::CaseSensitivity cs = Qt::CaseSensitive) const;
-//    s1.set((bool (QString::*)(const QString &, Qt::CaseSensitivity) const)ADDR(QString,contains),rettruestub);
-//    Stub s2;
-//    s2.set(ADDR(QFileInfo,size),retintstub);
+    Stub s1;
+    //bool contains(const QString &s, Qt::CaseSensitivity cs = Qt::CaseSensitive) const;
+    s1.set((bool (QString::*)(const QString &, Qt::CaseSensitivity) const)ADDR(QString,contains),rettruestub);
+    Stub s2;
+    s2.set(ADDR(QFileInfo,size),retintstub);
 
-//    intvalue = 1024*1024;
-//    wra->clearDoubleCharaterEncode();
+    intvalue = 1024*1024;
+    wra->clearDoubleCharaterEncode();
 
 
-//    EXPECT_NE(wra,nullptr);
-//    wra->deleteLater();
+    EXPECT_NE(wra,nullptr);
+    wra->deleteLater();
 }
 TEST(UT_Editwrapper_clearDoubleCharaterEncode, UT_Editwrapper_clearDoubleCharaterEncode_002)
 {
