@@ -1031,12 +1031,12 @@
     </message>
     <message>
         <source>Failed to paste text: it is too large</source>
-        <translation type="unfinished"/>
+        <translation type="vanished">Fallo al pegar el texto: es demasiado grande</translation>
     </message>
     <message>
         <location filename="../src/editor/dtextedit.cpp" line="2581"/>
         <source>Copy failed: not enough memory</source>
-        <translation type="unfinished"/>
+        <translation>Copia fallida: no hay suficiente memoria</translation>
     </message>
     <message>
         <location filename="../src/editor/dtextedit.cpp" line="2665"/>
@@ -1091,7 +1091,7 @@
     <message>
         <location filename="../src/editor/dtextedit.cpp" line="2591"/>
         <source>Paste failed: not enough memory</source>
-        <translation type="unfinished"/>
+        <translation>Fallo al pegar: no hay suficiente memoria</translation>
     </message>
     <message>
         <location filename="../src/editor/dtextedit.cpp" line="3439"/>
